<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;

class CadImgProdService {

	public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function findImgProducts($conditions) {
        $params = array(
            ':NRORG'         => $conditions['NRORG'],
         	':CDFILIAL'      => $conditions['CDFILIAL'],
         	':TCDPRODUTO'    => $conditions['TCDPRODUTO'],
         	':CDPRODUTO'     => $conditions['CDPRODUTO'],
         	':CDPRODUTOINI'  => $conditions['CDPRODUTOINI'],
         	':CDPRODUTOFIN'  => $conditions['CDPRODUTOFIN']
 		);
 		
        $result = $this->entityManager->getConnection()->fetchAll(self::GET_PRODUTOS, $params);
 		
 		return $result;
    }
    
    const GET_PRODUTOS = "
    SELECT 
        PR.CDPRODUTO, 
        PR.NMPRODUTO,
        CASE WHEN PR.LINKIMGPROD IS NULL THEN PR.LINKIMGPROD ELSE PG.FILESERVERURL || PR.LINKIMGPROD END AS LINKIMGPROD
    FROM 
        PRODUTO PR 
        JOIN PRODFILI PF ON PR.CDPRODUTO = PF.CDPRODUTO 
        LEFT JOIN PARAMGERAL PG ON PG.NRORG = PR.NRORG
    WHERE 
        PR.NRORG = :NRORG 
        AND PF.CDFILIAL = :CDFILIAL
        AND PF.IDATIVO = 'S'
        AND ((INSTR(:CDPRODUTO, PR.CDPRODUTO) <> 0) OR (:TCDPRODUTO = 'T') OR (PR.CDPRODUTO BETWEEN :CDPRODUTOINI AND :CDPRODUTOFIN))
    ";
    
    public function findProducts($conditions) {
        $params = array(
            ':NRORG'         => $conditions['NRORG'],
         	':CDFILIAL'      => $conditions['CDFILIAL']
 		);
        $result = $this->entityManager->getConnection()->fetchAll(self::GET_PRODUTOS_FILTER, $params);
 		
 		return $result;
    }
    
    const GET_PRODUTOS_FILTER = "
    SELECT  
        PR.CDARVPROD,
        PR.CDPRODUTO, 
        PR.NMPRODUTO
    FROM 
        PRODUTO PR 
        JOIN PRODFILI PF ON PR.CDPRODUTO = PF.CDPRODUTO
    WHERE 
        PR.NRORG = :NRORG 
        AND PF.IDATIVO = 'S'
        AND PF.CDFILIAL = :CDFILIAL
    ";
    
    public function findImagens($conditions) {
        $params = array(
            ':NRORG'         => $conditions['NRORG'],
         	':CDFILIAL'      => $conditions['CDFILIAL'],
         	':CDPRODUTO'     => $conditions['CDPRODUTO']
 		);
        $result = $this->entityManager->getConnection()->fetchAll(self::GET_IMG, $params);
 		
 		return $result;
    }
    
    const GET_IMG = "
    SELECT IP.CDIMAGEM, IP.NMIMAGEM, CASE WHEN IP.LINKIMGPROD IS NULL THEN IP.LINKIMGPROD ELSE PG.FILESERVERURL || IP.LINKIMGPROD END AS LINKIMGPROD, IP.CDFILIAL 
    FROM IMGPROD IP
        LEFT JOIN PARAMGERAL PG ON PG.NRORG = IP.NRORG 
        WHERE IP.CDFILIAL = :CDFILIAL
         AND IP.CDPRODUTO = :CDPRODUTO
         AND IP.NRORG     = :NRORG
        ORDER BY IP.CDIMAGEM
    ";
    
    public function deleteImgProd($conditions) {
        return $this->entityManager->getConnection()->executeQuery(self::DELETE_IMG,$conditions);
    }
    
    const DELETE_IMG = "
    DELETE FROM IMGPROD 
        WHERE CDFILIAL = :CDFILIAL
         AND CDPRODUTO = :CDPRODUTO
         AND NRORG     = :NRORG
         AND CDIMAGEM  = :CDIMAGEM
    ";
    
    public function updateImgProd($conditions) {
        return $this->entityManager->getConnection()->executeQuery(self::UPDATE_IMG,$conditions);
    }
    
    const UPDATE_IMG = "
    UPDATE IMGPROD
        SET NMIMAGEM = :NMIMAGEM,
            LINKIMGPROD = :LINKIMGPROD
        WHERE CDFILIAL = :CDFILIAL
            AND CDPRODUTO = :CDPRODUTO
            AND NRORG     = :NRORG
            AND CDIMAGEM  = :CDIMAGEM
    ";

    public function saveImg($conditions) {
        return $this->entityManager->getConnection()->executeQuery(self::INSERT_IMG,$conditions);
    }
    
    const INSERT_IMG = "
    INSERT INTO IMGPROD(CDPRODUTO, NMIMAGEM, NRORG, LINKIMGPROD, CDFILIAL, CDIMAGEM)
        VALUES(:CDPRODUTO, :NMIMAGEM, :NRORG, :LINKIMGPROD, :CDFILIAL, :CDIMAGEM)
    ";
    
    public function validImagens($conditions) {
        $result = $this->entityManager->getConnection()->fetchAll(self::VALID_IMG, $conditions);
 		return $result;
    }
    
    const VALID_IMG = "
    SELECT 1 FROM IMGPROD
    WHERE CDFILIAL = :CDFILIAL
         AND CDPRODUTO = :CDPRODUTO
         AND CDIMAGEM  = :CDIMAGEM
         AND NRORG     = :NRORG
    ";
    
}